@@ -83,6 +83,11 @@ class Error extends Message
      */
     protected $backtrace = array();
 
+    /**
+     * Hide location of errors
+     */
+    protected $hide_location = false;
+
     /**
      * Constructor
      *
@@ -146,6 +151,18 @@ class Error extends Message
         return $result;
     }
 
+    /**
+     * Toggles location hiding
+     *
+     * @param boolean $hide Whether to hide
+     *
+     * @return void
+     */
+    public function setHideLocation($hide)
+    {
+        $this->hide_location = $hide;
+    }
+
     /**
      * sets PMA\libraries\Error::$_backtrace
      *
@@ -441,7 +458,8 @@ class Error extends Message
      */
     public function isUserError()
     {
-        return $this->getNumber() & (E_USER_WARNING | E_USER_ERROR | E_USER_NOTICE);
+        return $this->hide_location ||
+            ($this->getNumber() & (E_USER_WARNING | E_USER_ERROR | E_USER_NOTICE));
     }
 
     /**
@@ -460,7 +478,7 @@ class Error extends Message
 
         /* Probably affected by open_basedir */
         if ($dest === FALSE) {
-            return $path;
+            return basename($path);
         }
 
         $Ahere = explode(
